#!/bin/bash

### File Size Totaller
### by Michael Lee
### v1.02, 2003-05-11

###   Introduction
#
#  I'm continually annoyed by most Unix environments' lack of a way to find
#  the total space that the files in a directory take up.  Here's my solution.
#
#  This script will likely fail for files whose names are sufficiently interesting.
#  This script has been superceded by the python script dirsize.py.
#

###   Installation
#
#  1. Place this script somewhere in your executable PATH.  
#  2. Make sure that echo, grep, awk, and colnum are also in your PATH.
#  3. Make sure all of the above are executable by the desired users (this means you).
#  4. Hope that you have compatible versions.
#

###   Usage
#
#  Give it the directory name, or use the -h flag for more verbose help.
#

###   Changelog
#
#  2003-05-11           v1.02
#                       + Tweaked usage statement and intro
#
#  2003-05-09           v1.01
#                       ! Bad check on argument count is now fixed
#
#  2003-05-06           v1.00, GPL
#

###   License
#
#  Copyright (C) 2003  Michael Lee <kirbysdl@yahoo.com>
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#  
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

# Require one or two parameters
if (( $# < 1 || $# > 2 )); then
  echo "Usage: $0 -h | --help"
  echo "       $0 [-R] <directory name>"
  exit;
fi

# Must give directory name
if (( $# == 1 )); then
  if [[ "$1" == "-R" ]]; then
    echo "Usage: $0 -h | --help"
    echo "       $0 [-R] <directory name>"
    exit;
  fi
fi

# Only -R flag supported
if (( $# == 2 )); then
  if [[ "$1" != "-R" ]]; then
    echo "Usage: $0 -h | --help"
    echo "       $0 [-R] <directory name>"
    exit;
  fi
fi

# Display help whenever help is first param
if [[ "$1" == "-h" || "$1" == "--help" ]]; then
  echo "Usage: $0 -h | --help"
  echo "       $0 [-R] <dir>"
  echo
  echo "Displays the total size, in bytes, of all the files in the given directory"
  echo
  echo "  -h, --help display this help and exit"
  echo "  -R         include files in subdirectories"
  echo "  <dir>      specifies the directory to process"
  echo
  echo "Send bugs to Michael Lee <kirbysdl@yahoo.com>."
  exit;
fi

if (( $# == 2 )); then
  ls -AFl -R $2 | grep -v '^total' | grep -v '/$' | grep -v ':$' | colnum 5 | grep -v "^$" | awk "{ n=\$0; {while(getline!=0) n=n+\$0;} print(n); }" ;
else
  ls -AFl $1 | grep -v '^total' | grep -v '/$' | grep -v ':$' | colnum 5 | grep -v "^$" | awk "{ n=\$0; {while(getline!=0) n=n+\$0;} print(n); }"
fi
